@@ -1023,16 +1023,6 @@ initializeWorkingObjects(const WorkingObjectsPtr &wo, InstanceDirToucherPtr &ins
 	if (options.get("integration_mode") == "standalone") {
 		instanceOptions.properties["standalone_engine"] = options.get("standalone_engine");
 	}
-	if (options.has("web_server_config_files")) {
-		vector<string> configFiles = options.getStrSet("web_server_config_files");
-		Json::Value array(Json::arrayValue);
-
-		foreach (string configFile, configFiles) {
-			array.append(configFile);
-		}
-
-		instanceOptions.properties["web_server_config_files"] = array;
-	}
 	wo->instanceDir = boost::make_shared<InstanceDirectory>(instanceOptions,
 		options.get("instance_registry_dir"));
 	options.set("instance_dir", wo->instanceDir->getPath());
