@@ -131,7 +131,7 @@ starting_watchdog_after_fork(void *paramCycle, void *paramParams) {
     ngx_cycle_t *cycle = (void *) paramCycle;
     PsgVariantMap *params = (void *) paramParams;
 
-    const char  *log_filename;
+    char        *log_filename;
     FILE        *log_file;
     ngx_core_conf_t *ccf;
     ngx_uint_t   i;
@@ -142,7 +142,7 @@ starting_watchdog_after_fork(void *paramCycle, void *paramParams) {
      * Make sure that they're both redirected to the log file.
      */
     log_file = NULL;
-    log_filename = (const char *) psg_variant_map_get_optional(params, "log_file");
+    log_filename = psg_variant_map_get_optional(params, "log_file");
     if (log_filename == NULL) {
         ngx_log_error(NGX_LOG_ALERT, cycle->log, 0,
                 "no passenger log file configured, discarding log output");
@@ -152,6 +152,8 @@ starting_watchdog_after_fork(void *paramCycle, void *paramParams) {
             ngx_log_error(NGX_LOG_ALERT, cycle->log, ngx_errno,
                     "could not open the passenger log file for writing during Nginx startup, some log lines might be lost (will retry from Passenger core)");
         }
+        free(log_filename);
+        log_filename = NULL;
     }
 
     if (log_file == NULL) {
@@ -223,7 +225,6 @@ start_watchdog(ngx_cycle_t *cycle) {
     ngx_core_conf_t *core_conf;
     ngx_int_t        ret, result;
     ngx_uint_t       i;
-    char            *config_file = NULL;
     ngx_str_t       *prestart_uris;
     char           **prestart_uris_ary = NULL;
     ngx_keyval_t    *ctl = NULL;
@@ -243,11 +244,6 @@ start_watchdog(ngx_cycle_t *cycle) {
     pp_app_type_detector_set_throttle_rate(pp_app_type_detector,
         passenger_main_conf.stat_throttle_rate);
 
-    config_file = ngx_str_null_terminate(&cycle->conf_file);
-    if (config_file == NULL) {
-        goto error_enomem;
-    }
-
     prestart_uris = (ngx_str_t *) passenger_main_conf.prestart_uris->elts;
     prestart_uris_ary = calloc(sizeof(char *), passenger_main_conf.prestart_uris->nelts);
     for (i = 0; i < passenger_main_conf.prestart_uris->nelts; i++) {
@@ -258,7 +254,6 @@ start_watchdog(ngx_cycle_t *cycle) {
     }
 
     psg_variant_map_set_int    (params, "web_server_control_process_pid", getpid());
-    psg_variant_map_set_strset (params, "web_server_config_files", (const char **) &config_file, 1);
     psg_variant_map_set        (params, "server_software", NGINX_VER, strlen(NGINX_VER));
     psg_variant_map_set_bool   (params, "multi_app", 1);
     psg_variant_map_set_bool   (params, "load_shell_envvars", 1);
@@ -348,7 +343,6 @@ cleanup:
     psg_variant_map_free(params);
     free(passenger_root);
     free(error_message);
-    free(config_file);
     if (prestart_uris_ary != NULL) {
         for (i = 0; i < passenger_main_conf.prestart_uris->nelts; i++) {
             free(prestart_uris_ary[i]);
